@@ -17,8 +17,10 @@
 #with this program; if not, write to the Free Software Foundation, Inc.,
 #51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-from fiabilipy.system import System, Component, Voter
+from fiabilipy.component import Component
+from fiabilipy.voter import Voter
+from fiabilipy.system import System
 from fiabilipy.markov import Markovprocess
 
+__version__ = '2.7'
 __all__ = ['System', 'Component', 'Voter', 'Markovprocess']
-__version__ = '2.2'
