@@ -76,6 +76,7 @@ class Markovprocess(object):
         else:
             self.initstates = array(initstates)
         self._initmatrix()
+        self._states = {}
 
     def _initmatrix(self):
         r""" Given a list of components, this function initialize the markov
@@ -101,7 +102,7 @@ class Markovprocess(object):
         rowsum = self.matrix.sum(axis=1)
         self.matrix[xrange(2**N), xrange(2**N)] = -rowsum
 
-    def computestates(self, func):
+    def _computestates(self, func):
         r""" Compute the states described by a function
 
             Parameters
@@ -143,16 +144,15 @@ class Markovprocess(object):
                 states.append(x)
         return states
 
-    def value(self, t, states=None):
+    def value(self, t, statefunc=None):
         r""" Compute the probability of being in some states.
 
             Parameters
             ----------
             t : float
                 when the probability must be computed
-            states : list of states
-                for which states the probability must be computed. If not given,
-                it return the probability of each possible state.
+            state : function
+                a function defining the state you want to know the probability
 
             Examples
             --------
@@ -160,8 +160,7 @@ class Markovprocess(object):
             >>> comp = (A, B, C, D)
             >>> process = Markovprocess(comp, {0:1})
             >>> availablefunc = lambda x: (x[0] or x[1]) and (x[2] or x[3])
-            >>> availablestates = process.computestates(states)
-            >>> process.value(100, states=availablestates)
+            >>> process.value(100, statefunc=availablefunc)
             0.98197017562069511
 
             So, at :math:`t = 100`, the probability for the system to be
@@ -176,9 +175,15 @@ class Markovprocess(object):
             0.031471429479129759
         """
         v = self.initstates.dot(expm(t*self.matrix))
-        if not states :
+        if not statefunc:
             return v
-        else :
+        else:
+            try:
+                states = self._states[statefunc]
+            except KeyError:
+                states = self._computestates(statefunc)
+                self._states[statefunc] = states
+
             return v[(states, )].sum()
 
     def draw(self, output=None):
