@@ -22,8 +22,7 @@ import unittest2
 
 from random import random
 
-from system import Component, System
-from markov import Markovprocess
+from fiabilipy import System, Component, Markovprocess
 
 class TestMarkov(unittest2.TestCase):
 #The reliabily and the availability of systems is already tested. Let’s
@@ -71,12 +70,11 @@ class TestMarkov(unittest2.TestCase):
         #Let’s build the markov equivalent system
         self.components = (alim[0], alim[1], motors[0], motors[1])
         self.process = Markovprocess(self.components, {0:1}) #All the components work
-        scompute = self.process.computestates
 
         self.states = {
-            'series-parallel': scompute(lambda x : (x[0]*x[2]) + (x[1]*x[3])),
-            'parallel-series': scompute(lambda x : (x[0]+x[1]) * (x[2]+x[3])),
-            'simple': scompute(lambda x : x[0]*x[2]),
+            'series-parallel': lambda x : (x[0]*x[2]) + (x[1]*x[3]),
+            'parallel-series': lambda x : (x[0]+x[1]) * (x[2]+x[3]),
+            'simple': lambda x : x[0]*x[2],
         }
 
         self.systems = systems
@@ -89,7 +87,7 @@ class TestMarkov(unittest2.TestCase):
         for _ in xrange(maxiter):
             t = random() * maxtime
             for name, states in self.states.iteritems():
-                self.assertAlmostEqual(self.process.value(t, states=states),
+                self.assertAlmostEqual(self.process.value(t, states),
                                        self.systems[name].availability(t))
 
 if __name__ == '__main__':
