@@ -20,8 +20,10 @@
 from __future__ import print_function, absolute_import
 import unittest2
 
-from system import Component, Voter, System
 from sympy import symbols, exp
+from networkx import DiGraph, is_isomorphic
+
+from fiabilipy import Component, Voter, System
 
 class TestComponent(unittest2.TestCase):
     """ Test the Component class.
@@ -235,17 +237,50 @@ class TestSystem(unittest2.TestCase):
         #from a list
         system['E'] = [component[0], component[1]]
         system[component[0]] = 'S'
-        self.assertEqual(system._graph, {'E':[component[0], component[1]],
-                                         component[0]:'S'})
+        wanted = DiGraph({'E':[component[0], component[1]], component[0]:['S']})
+        self.assertTrue(is_isomorphic(system._graph, wanted))
+
         del system[component[0]] #This component isn’t used anymore
         #from a single element
         system['E'] = component[1]
         system[component[1]] = 'S'
-        self.assertEqual(system._graph, {'E':[component[1]],
-                                         component[1]:'S'})
+        wanted = DiGraph({'E':[component[1]], component[1]:'S'})
+        self.assertTrue(is_isomorphic(system._graph, wanted))
 
+    def test_cache(self):
+        """ Perfom some tests on the cache
+        """
+        components = [Component('C{}'.format(i), 1e-3) for i in (0, 1, 2)]
+        system = System()
+
+        #      +-- C0 --+
+        #      |        |
+        # E ---|        +-- C2 -- S
+        #      |        |
+        #      +-- C1 --+
+
+        system['E'] = [components[0], components[1]]
+        system[components[0]] = components[2]
+        system[components[1]] = components[2]
+        system[components[2]] = 'S'
+
+        self.assertAlmostEqual(system.mttf, 2000/3.)
+        self.assertIn('mttf', system._cache) #The mttf is cached
+
+        components[0].lambda_ = 0.05 #Let’s change the failure rate
+        self.assertEqual(system._cache, dict()) #The cache is now empty
+        self.assertAlmostEqual(system.mttf, 331750/663.)
+        self.assertIn('mttf', system._cache) #The mttf is cached
+
+        #now, check if it works with a shared component
+        othersystem = System()
+        othersystem['E'] = components[0]
+        othersystem[components[0]] = 'S'
+
+        self.assertAlmostEqual(othersystem.mttf, 20)
+        components[0].lambda_ = 2e-4
+        self.assertAlmostEqual(othersystem.mttf, 5000)
+        self.assertAlmostEqual(system.mttf, 29000/33.)
 
 if __name__ == '__main__':
     unittest2.main()
-
-
